# [NB] We do not provide the validation layers here yet, for simplicity.
# The goal is to just let our users try Vulkan-based games, etc.

%define	srcname Vulkan-LoaderAndValidationLayers

%define	major 1
%define	libname %mklibname vulkan %{major}
%define	devname %mklibname vulkan -d

# No major in soname
%define	libvklayer_utils %mklibname vklayer_utils

Summary:	Vulkan Installable Client Driver (ICD) Loader
Name:		vulkan
Version:	1.0.68.0
Release:	6
License:	ASL 2.0
Group:		Graphics
Url:		https://github.com/KhronosGroup/Vulkan-LoaderAndValidationLayers
Source0:	https://github.com/KhronosGroup/%{srcname}/archive/sdk-%{version}.tar.gz?/%{srcname}-%{version}.tar.xz
Source1:	https://raw.githubusercontent.com/KhronosGroup/glslang/master/SPIRV/spirv.hpp
# Need for vkd3d
Source2:	https://raw.githubusercontent.com/KhronosGroup/glslang/master/SPIRV/GLSL.std.450.h
Source3:	https://raw.githubusercontent.com/KhronosGroup/SPIRV-Headers/master/include/spirv/unified1/spirv.h
Source100:	%{name}.rpmlintrc
# From Fedora
Patch0:		0003-layers-Don-t-set-an-rpath.patch
Patch1:		0008-demos-Don-t-build-tri-or-cube.patch

Patch2:		vulkan-0002-ignore-generating-spirv_tools_commit_id.h.patch
Patch3:		vulkan-1.0.68.0-double-slash-in-path.patch
Patch4:		vulkan-1.0.68.0-fix-libdir-in-pkgconfig-file.patch

BuildRequires:	bison
BuildRequires:	cmake
BuildRequires:	python3
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	pkgconfig(pciaccess)
BuildRequires:	pkgconfig(wayland-client)
BuildRequires:	pkgconfig(wayland-cursor)
BuildRequires:	pkgconfig(wayland-server)
BuildRequires:	pkgconfig(wayland-egl)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xcb)
BuildRequires:	pkgconfig(xrandr)

Requires:	%{libname} = %{EVRD}

%description
Vulkan is a new generation graphics and compute API that provides
high-efficiency, cross-platform access to modern GPUs used in a wide variety of
devices from PCs and consoles to mobile phones and embedded platforms.
This package contains the common files and utilies for Vulkan.

%files
%doc LICENSE.txt COPYRIGHT.txt
%doc README.md CONTRIBUTING.md
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/icd.d
%{_bindir}/vulkaninfo

#----------------------------------------------------------------------------

%package -n %{libname}
Summary:	Vulkan ICD Loader Library
Group:		System/Libraries

%description -n %{libname}
This package contains the installable client driver (ICD) loader library
for Vulkan.

%files -n %{libname}
%doc LICENSE.txt
%{_libdir}/libvulkan.so.%{major}*

#----------------------------------------------------------------------------

%package -n %{libvklayer_utils}
Summary:	Vulkan Layer Library
Group:		System/Libraries
Conflicts:	%{_lib}vulkan-devel < 1.0.68.0-5

%description -n %{libvklayer_utils}
This package contains the installable layer library for Vulkan.

%files -n %{libvklayer_utils}
%doc LICENSE.txt
%{_libdir}/libVkLayer_utils.so

#----------------------------------------------------------------------------

%package -n %{devname}
Summary:	Development files for %{libname}
Group:		Development/C
Requires:	%{name} = %{EVRD}
Requires:	%{libname} = %{EVRD}
Requires:	%{libvklayer_utils} = %{EVRD}
Provides:	%{name}-devel = %{EVRD}

%description -n %{devname}
This package contains the development files for Vulkan applications.

%files -n %{devname}
%doc LICENSE.txt
%{_includedir}/%{name}/
%{_libdir}/libvulkan.so
%{_libdir}/pkgconfig/%{name}.pc

#----------------------------------------------------------------------------

%prep
%setup -qn %{srcname}-%{version}
%apply_patches


%build
cp %{SOURCE1} .
%cmake \
	-DBUILD_TESTS=OFF \
	-DBUILD_LAYERS=OFF \
	-DBUILD_VKJSON=OFF \
	-DBUILD_WSI_XCB_SUPPORT=ON \
	-DBUILD_WSI_XLIB_SUPPORT=ON \
	-DBUILD_WSI_WAYLAND_SUPPORT=ON \
	-DBUILD_WSI_MIR_SUPPORT=OFF \
	-DCMAKE_INSTALL_SYSCONFDIR:PATH=%{_sysconfdir} \
	-DGLSLANG_SPIRV_INCLUDE_DIR=../

%make


%install
%makeinstall_std -C build

install -d -m 755 %{buildroot}%{_includedir}
cp -a include/%{name} %{buildroot}%{_includedir}

install -d -m 755 %{buildroot}%{_sysconfdir}/%{name}/icd.d

cp %{SOURCE2} %{SOURCE3} %{buildroot}%{_includedir}/%{name}/


%changelog

* Fri Jun 08 2018 survolog <survolog@yandex.ru> 1.0.68.0-6
- (8f915d7) Merge pull request #1 from survolog/vulkan:rosa2016.1
- (8f915d7) Added spirv.h and GLSL.std.450.h for vkd3d


